Normalized process exit information shared by the runtime and provider profiles.
Summary
Functions
Normalizes raw subprocess exit reasons into a stable struct.
Returns true when the normalized exit represents success.
Types
Functions
Normalizes raw subprocess exit reasons into a stable struct.
This includes raw integer exit statuses, including the shifted values some
platforms report as code * 256.
Returns true when the normalized exit represents success.